@@ -10,6 +10,8 @@ import uuid
 from functools import partial
 from numbers import Number
 
+from typing import Any, Callable, Optional
+
 from six.moves import queue
 
 from ray.util.debug import log_once
@@ -446,6 +448,9 @@ class FunctionRunner(Trainable):
 
         checkpoint_path = TrainableUtil.process_checkpoint(
             checkpoint, parent_dir, state)
+
+        self._maybe_save_to_cloud()
+
         return checkpoint_path
 
     def save_to_object(self):
@@ -530,16 +535,14 @@ class FunctionRunner(Trainable):
             pass
 
 
-def wrap_function(train_func, durable=False, warn=True):
+def wrap_function(train_func: Callable[[Any], Any],
+                  warn: bool = True,
+                  name: Optional[str] = None):
     inherit_from = (FunctionRunner, )
 
     if hasattr(train_func, "__mixins__"):
         inherit_from = train_func.__mixins__ + inherit_from
 
-    if durable:
-        from ray.tune import DurableTrainable
-        inherit_from = (DurableTrainable, ) + inherit_from
-
     func_args = inspect.getfullargspec(train_func).args
     use_checkpoint = detect_checkpoint_function(train_func)
     use_config_single = detect_config_single(train_func)
@@ -562,8 +565,11 @@ def wrap_function(train_func, durable=False, warn=True):
                 "arguments to be `func(config, checkpoint_dir=None)`.")
 
     class ImplicitFunc(*inherit_from):
-        _name = train_func.__name__ if hasattr(train_func, "__name__") \
-            else "func"
+        _name = name or (train_func.__name__
+                         if hasattr(train_func, "__name__") else "func")
+
+        def __repr__(self):
+            return self._name
 
         def _trainable_func(self, config, reporter, checkpoint_dir):
             if not use_checkpoint and not use_reporter:
